/* Copyright 2013 Akira Ohta (akohta001@gmail.com)
    This file is part of ntch.

    The ntch is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The ntch is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with ntch.  If not, see <http://www.gnu.org/licenses/>.
    
*/
#ifndef _2CH_H_
#define _2CH_H_

#include "net/nt_cookie.h"
#include "_2ch/model_2ch.h"
#include "_2ch/maru_2ch.h"
#include "_2ch/search_2ch.h"


extern char *URL_2CH_BOARDMENU;


extern nt_2ch_model_handle app_2ch_model;

extern BOOL nt_2ch_model_init();
extern BOOL nt_init_board_menu();
extern BOOL nt_read_board(nt_2ch_selected_item_handle h_select);
extern BOOL nt_read_thread(nt_2ch_selected_item_handle h_select);
extern BOOL nt_write_msg(nt_2ch_selected_item_handle h_select,
			nt_write_data_handle h_write_data, nt_cookie_tp cookiep, 
			nt_maru_2ch_tp marup);

extern BOOL nt_set_sel_item(nt_2ch_model_handle h_model,
			nt_2ch_selected_item_handle *h_sel_itemp, 
			nt_searched_thread_handle h_sel_thread, const wchar_t** errorpp);
extern int nt_read_board_list(nt_link_tp selitem_list);

#endif /* _2CH_H_ */
